@@ -57,7 +57,8 @@ GsShellCategory	*gs_shell_category_new		(void);
 void		 gs_shell_category_set_category	(GsShellCategory	*shell_category,
 						 GsCategory		*category);
 GsCategory	*gs_shell_category_get_category (GsShellCategory	*shell_category);
-void		 gs_shell_category_refresh	(GsShellCategory	*shell_category);
+void		 gs_shell_category_switch_to	(GsShellCategory	*shell_category);
+void		 gs_shell_category_reload	(GsShellCategory	*shell_category);
 void		 gs_shell_category_setup	(GsShellCategory	*shell_category,
 						 GsShell		*shell,
 						 GsPluginLoader		*plugin_loader,
