@@ -41,6 +41,7 @@ struct GsShellSearchPrivate
 	GtkSizeGroup		*sizegroup_image;
 	GtkSizeGroup		*sizegroup_name;
 	GsShell			*shell;
+	gchar			*appid_to_show;
 	gchar			*value;
 
 	GtkWidget		*list_box_search;
@@ -251,10 +252,16 @@ gs_shell_search_get_search_cb (GObject *source_object,
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source_object);
 	GtkWidget *app_row;
 
-	gs_stop_spinner (GTK_SPINNER (priv->spinner_search));
-
 	list = gs_plugin_loader_search_finish (plugin_loader, res, &error);
 	if (list == NULL) {
+		if (g_error_matches (error,
+		                     G_IO_ERROR,
+		                     G_IO_ERROR_CANCELLED)) {
+			g_debug ("search cancelled");
+			g_error_free (error);
+			goto out;
+		}
+
 		if (g_error_matches (error,
 				     GS_PLUGIN_LOADER_ERROR,
 				     GS_PLUGIN_LOADER_ERROR_NO_RESULTS)) {
@@ -264,9 +271,12 @@ gs_shell_search_get_search_cb (GObject *source_object,
 				   error->message);
 		}
 		g_error_free (error);
+		gs_stop_spinner (GTK_SPINNER (priv->spinner_search));
 		gtk_stack_set_visible_child_name (GTK_STACK (priv->stack_search), "no-results");
 		goto out;
 	}
+
+	gs_stop_spinner (GTK_SPINNER (priv->spinner_search));
 	gtk_stack_set_visible_child_name (GTK_STACK (priv->stack_search), "results");
 	for (l = list; l != NULL; l = l->next) {
 		app = GS_APP (l->data);
@@ -282,6 +292,11 @@ gs_shell_search_get_search_cb (GObject *source_object,
 		gtk_widget_show (app_row);
 	}
 
+	if (priv->appid_to_show != NULL) {
+		gs_shell_show_details (priv->shell, priv->appid_to_show);
+		g_clear_pointer (&priv->appid_to_show, g_free);
+	}
+
 out: ;
 }
 
@@ -331,6 +346,21 @@ gs_shell_search_reload (GsShellSearch *shell_search)
 		gs_shell_search_load (shell_search);
 }
 
+
+/**
+ * gs_shell_search_set_appid_to_show:
+ *
+ * Switch to the specified app id after loading the search results.
+ **/
+void
+gs_shell_search_set_appid_to_show (GsShellSearch *shell_search, const gchar *appid)
+{
+	GsShellSearchPrivate *priv = shell_search->priv;
+
+	g_free (priv->appid_to_show);
+	priv->appid_to_show = g_strdup (appid);
+}
+
 /**
  * gs_shell_search_switch_to:
  **/
@@ -358,9 +388,6 @@ gs_shell_search_switch_to (GsShellSearch *shell_search, const gchar *value, gboo
                 gtk_adjustment_set_value (adj, gtk_adjustment_get_lower (adj));
         }
 
-	if (g_strcmp0 (value, priv->value) == 0)
-		return;
-
 	g_free (priv->value);
 	priv->value = g_strdup (value);
 
@@ -576,6 +603,7 @@ gs_shell_search_finalize (GObject *object)
 	if (priv->search_cancellable != NULL)
 		g_object_unref (priv->search_cancellable);
 
+	g_free (priv->appid_to_show);
 	g_free (priv->value);
 
 	G_OBJECT_CLASS (gs_shell_search_parent_class)->finalize (object);
