@@ -69,6 +69,7 @@ struct GsShellPrivate
 	GtkBuilder		*builder;
 	GtkWindow		*main_window;
 	GQueue			*back_entry_stack;
+	gboolean		 ignore_next_search_changed_signal;
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (GsShell, gs_shell, G_TYPE_OBJECT)
@@ -410,9 +411,16 @@ window_keypress_handler (GtkWidget *window, GdkEvent *event, GsShell *shell)
 }
 
 static void
-search_changed_handler (GObject *entry, GsShell *shell) {
+search_changed_handler (GObject *entry, GsShell *shell)
+{
+	GsShellPrivate *priv = shell->priv;
 	const gchar *text;
 
+	if (priv->ignore_next_search_changed_signal) {
+		priv->ignore_next_search_changed_signal = FALSE;
+		return;
+	}
+
 	text = gtk_entry_get_text (GTK_ENTRY (entry));
 
 	if (text[0] == '\0' && gs_shell_get_mode (shell) == GS_SHELL_MODE_SEARCH) {
@@ -487,6 +495,17 @@ gs_shell_updates_changed_cb (GsPluginLoader *plugin_loader, GsShell *shell)
 	gs_shell_updates_reload (priv->shell_updates);
 }
 
+/**
+ * gs_shell_main_window_mapped_cb:
+ */
+static void
+gs_shell_main_window_mapped_cb (GtkWidget *widget, GsShell *shell)
+{
+	GsShellPrivate *priv = shell->priv;
+	gs_plugin_loader_set_scale (priv->plugin_loader,
+				    gtk_widget_get_scale_factor (widget));
+}
+
 /**
  * gs_shell_setup:
  */
@@ -506,6 +525,8 @@ gs_shell_setup (GsShell *shell, GsPluginLoader *plugin_loader, GCancellable *can
 	/* get UI */
 	priv->builder = gtk_builder_new_from_resource ("/org/gnome/Software/gnome-software.ui");
 	priv->main_window = GTK_WINDOW (gtk_builder_get_object (priv->builder, "window_software"));
+	g_signal_connect (priv->main_window, "map",
+			  G_CALLBACK (gs_shell_main_window_mapped_cb), shell);
 
 	/* add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
@@ -654,6 +675,10 @@ gs_shell_get_installed_updates_cb (GsPluginLoader *plugin_loader,
 				     GS_PLUGIN_LOADER_ERROR,
 				     GS_PLUGIN_LOADER_ERROR_NO_RESULTS)) {
 			g_debug ("no updates to show");
+		} else if (g_error_matches (error,
+		                            G_IO_ERROR,
+		                            G_IO_ERROR_CANCELLED)) {
+			g_debug ("get updates cancelled");
 		} else {
 			g_warning ("failed to get updates: %s", error->message);
 		}
@@ -697,6 +722,9 @@ gs_shell_show_sources (GsShell *shell)
 	GtkWidget *dialog;
 
 	dialog = gs_sources_dialog_new (priv->main_window, priv->plugin_loader);
+	g_signal_connect_swapped (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  dialog);
 	gtk_window_present (GTK_WINDOW (dialog));
 }
 
@@ -734,64 +762,32 @@ gs_shell_show_filename (GsShell *shell, const gchar *filename)
 	gs_shell_activate (shell);
 }
 
-typedef struct {
-	GsShell *shell;
-	GsApp *app;
-} RefineData;
-
-static void
-refine_cb (GObject *source,
-	   GAsyncResult *res,
-	   gpointer data)
-{
-	RefineData *refine = data;
-	GsShellPrivate *priv = refine->shell->priv;
-	GError *error = NULL;
-
-        if (!gs_plugin_loader_app_refine_finish (priv->plugin_loader,
-                                                 res,
-                                                 &error)) {
-                g_warning ("%s", error->message);
-                g_error_free (error);
-		goto out;
-        }
-
-        refine->app = gs_plugin_loader_dedupe (priv->plugin_loader, refine->app);
-        gs_shell_show_app (refine->shell, refine->app);
-
-out:
-        g_object_unref (refine->app);
-	g_free (refine);
-}
-
 void
 gs_shell_show_search_result (GsShell *shell, const gchar *id, const gchar *search)
 {
 	GsShellPrivate *priv = shell->priv;
 	GtkWidget *widget;
-	RefineData *refine;
 
-	if (search != NULL && search[0] != '\0') {
-		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "entry_search"));
-		gtk_entry_set_text (GTK_ENTRY (widget), search);
-		gs_shell_search_switch_to (priv->shell_search, search, TRUE);
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "entry_search"));
 
-		gs_shell_change_mode (shell, GS_SHELL_MODE_SEARCH, NULL, NULL, TRUE);
-	}
+	/* ignore next "search-changed" signal to avoid getting a callback
+         * after 150 ms and messing up the state */
+	priv->ignore_next_search_changed_signal = TRUE;
+	gtk_entry_set_text (GTK_ENTRY (widget), search);
 
-	refine = g_new0 (RefineData, 1);
-	refine->shell = shell;
-	refine->app = gs_app_new (id);
-	gs_plugin_loader_app_refine_async (priv->plugin_loader,
-					   refine->app,
-					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_LICENCE |
-					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_SIZE |
-					   GS_PLUGIN_REFINE_FLAGS_REQUIRE_URL,
-					   priv->cancellable,
-					   refine_cb,
-					   refine);
+	gs_shell_search_set_appid_to_show (priv->shell_search, id);
+	gs_shell_change_mode (shell, GS_SHELL_MODE_SEARCH, NULL, NULL, TRUE);
 }
 
+void
+gs_shell_show_details (GsShell *shell, const gchar *id)
+{
+	GsApp *app;
+
+	app = gs_app_new (id);
+	gs_shell_show_app (shell, app);
+	g_object_unref (app);
+}
 
 /**
  * gs_shell_class_init:
